/* Rexx program to test access to the class 'datergf.DateTimeRGF'; 2003-05-10, ---rgf

   Make sure that *this* directory is in your %CLASSPATH%, otherwise
   the program cannot find the Java "datergf"-package (subdirectory of this one)*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."


.bsf~import("DateTimeRGF",   "datergf.DateTimeRGF")     /* import the Java class*/
.bsf~import("DateFormatRGF", "datergf.DateFormatRGF")   /* import the Java class*/

dt1 = .DateTimeRGF~new                  /* create and get a DateTimeRGF object  */
say dt1~toString                        /* show its value                       */

dt1~update                              /* set to now                           */
say dt1~toString                        /* show the values                      */
say

i=3
say "now sleeping for" i "seconds ..."
call bsf 'sleep', i                     /* sleep i seconds using bsf4rexx       */
dt1~update                              /* set to now                           */
say dt1~toString                        /* show the values                      */

say
date1 = dt1~bsf.getFieldValue("date")   /* get DateRGF field                    */
say "date-portion:" date1~toString

                                        /* determine ISO-week, using a public static
                                           field of the interface "DTC"         */
week=date1~get(.bsf~getStaticValue("datergf.DTC", "WEEK") )
say "today falls into ISO-week #" week
say

time1 = dt1~bsf.getFieldValue("time")   /* get TimeRGF field                    */
say "time-portion:" time1~toString
say

easter = date1~easter(date1)       /* get Easter sunday for this year      */
week=easter~get(.bsf~getStaticValue("datergf.DTC", "WEEK") )
say "This year Easter sunday is:" easter~toString "which is ISO-week #" week
say


bStrict=random(0, 1)    /* determine which version should be used to create the Java object */
tmp=""
if bStrict then
do
   dLastFebruaryOf2008=bsf('registerBeanStrict', , "datergf.DateTimeRGF","int", 2008, "int", "3", "int", '0', "int", 1, "int", 2, "int", 3)
   tmp=" with strict data typing!"
end
else
do
   dLastFebruaryOf2008=.dateTimeRgf~new(2008, 3, 0, 9, 8, 7)
end

say "Last February in 2008 is:" bsf('invoke', dLastFebruaryOf2008, "toString")
say "     (hint: told to produce 0th March"tmp")"
say
say "---"
say

say "This demos the Java class 'DateFormatRGF':"
say
say "   the format string being used is:"
say

formatString="'Today is:' [EEEE], d. [MMM] yyyy, 'day #:' D (g 'to go'), hh:mm:ss.SSS [a]"
say formatString
say

df = .dateFormatRGF~new         /* get an instance of the dateformatter */

say df~format(formatString, dt1)
say "   ---"
say "   (now localizing the names of the months and days as well as the 'am/pm')"
df~localize
say df~format(formatString, dt1)
say "   the default formatting now produces:" '[' || dt1~toString || ']'
say "---"
say

locales.1="ITALIAN"
locales.2="FRENCH"
locales.3="UK"
locales.4="US"
locales.5="JAPANESE"
locales.0=5     /* indicate # of elements in stem ("hash")      */

do i=1 to locales.0
   say "trying to get the" locales.i "Locale from Java ("i "of" locales.0") ..."
   df~localize(.bsf~getStaticValue("java.util.Locale", locales.i))
   say df~format(formatString, dt1)
   say "   the default formatting now produces:" '[' || dt1~toString || ']'
   say "---"
end


say "More on the Java package 'datergf' can be found at:"
say
say "   http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/datergf/"
say
say "or check the Internet starting with:"
say
say "   http://www.RexxLA.org"

::requires BSF.CLS            -- get the direct Object Rexx BSF support

