/*
   Name:    "ShootOut-oo.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in ShootOut-oo.rex"
                or
            "java com.ibm.bsf.Main            -in ShootOut-oo.rex"
                or
            "rexxj ShootOut-oo.rex"
                or
            "rexx ShootOut-oo.rex"

   Purpose:  create a window with a choice-object and two text-fields and buttons;
             if the ok-button is pressed then popup another window and display what
             was chosen and entered.

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx"
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-21, 2003-05-10

   Author:   Rony G. Flatscher, WU Wien University,
*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."


        /* import Java classes          */
.bsf~import("awtButton",        "java.awt.Button")
.bsf~import("awtFrame",         'java.awt.Frame')
.bsf~import("awtGBConstraints", 'java.awt.GridBagConstraints')
.bsf~import("awtGridBagLayout", 'java.awt.GridBagLayout')
.bsf~import("awtInsets",        'java.awt.Insets')
.bsf~import("awtLabel",         "java.awt.Label")
.bsf~import("awtTextArea",      "java.awt.TextArea")

        /* create labels                */
label1 = .awtLabel~new('Your question?')
label2 = .awtLabel~new(, 'Well, consider this answer:' )

        /* get static values from class */
scrNone   = .bsf~getStaticValue('java.awt.TextArea', 'SCROLLBARS_NONE')
scrVert   = .bsf~getStaticValue('java.awt.TextArea', 'SCROLLBARS_VERTICAL_ONLY')

        /* create text area objects     */
taQuery  = .awtTextArea~new("",  5, 80, scrNone)
taAnswer = .awtTextArea~new("", 15, 80, scrVert)

        /* make the answer text area non-editable       */
taAnswer~setEditable(.false)

        /* create the buttons           */
butAnswer = .awtButton~new(' Please answer me! ')
butLeave  = .awtButton~new(' Let us stop for dooday, o.k.? ' )

        /* create gridBagLayout & constraint    */
lay    = .awtGridBagLayout~new
layCon = .awtGBConstraints~new

        /* now define details of the GridBagLayout      */
layCon~bsf.setFieldValue( 'fill',       bsf('getFieldValue', layCon, 'HORIZONTAL'))
layCon~bsf.setFieldValue( 'gridwidth',  bsf('getFieldValue', layCon, 'REMAINDER' ))

inset = .awtInsets~new(5, 5, 5, 5)
layCon~bsf.setFieldValue( 'insets',     inset)

        /* register the constraints with the layout manager     */
lay ~~setConstraints(label1,    layCon)
lay ~~setConstraints(taQuery,   layCon)
lay ~~setConstraints(butAnswer, layCon)
lay ~~setConstraints(label2,    layCon)
lay ~~setConstraints(taAnswer,  layCon)
lay ~~setConstraints(butLeave,  layCon)

        /* create the frame window                              */
window = .awtFrame~new('ShootOut!')

        /* now add controls to window, change some settings of it       */
window ~~setLayout(lay)
window ~~add(label1) ~~add(taQuery)  ~~add(butAnswer)
window ~~add(Label2) ~~add(taAnswer) ~~add(butLeave)

        /* pack the elements, show the window, bring it to the front    */
window ~~pack ~~show ~~toFront

        /* define the events we are interested in and the text to be sent to us */
window    ~ bsf.addEventListener('window', 'windowClosing', 'call BSF "exit"')
butAnswer ~ bsf.addEventListener('action', '', 'call answer taQuery, taAnswer, answers')
butLeave  ~ bsf.addEventListener('action', '', 'call BSF "exit"')

answers = .stream~new( "ShootAnswers.txt")~arrayin      /* read answers from file       */

do forever      /* wait and fetch the text to be sent by Java           */
   a = bsf("pollEventText")     /* wait for an eventText to be sent     */
   interpret a                  /* execute as a Rexx program    */
   if result= "SHUTDOWN, REXX !" then leave     /* JVM will be shutdown */
end
exit

::requires BSF.CLS    -- "requires" must be the first of the directives,
                        -- this one is needed for getting access to the Object Rexx
                        -- BSF wrapper classes

        /* react to pressing the answer button  */
::routine answer
   use  arg taQuery, taAnswer, answers  /* get names of TextAreas       */
   txt=taQuery~getText                  /* get text             */

   lf = "0a"x
   txt=txt~translate("  ", "0d0a"x)~space~strip('T')
   if txt~right(1) = "?" then           /* a question in hand?          */
   do
      newLine = "0a0a"x
      tmp     =        newLine || "*** your question: ***" || newLine || txt
      tmp     = tmp || newLine || "--- my answer to you! ---" || newLine
      pick    = random(1, answers~items)/* pick a number        */
      tmp     = tmp || answers~at(pick)

      call bsf 'invoke', taAnswer, 'append',  tmp /* append to answer text area   */
      call bsf 'invoke', taQuery,  'setText', ""
   end
   return

